@@ -36,7 +36,7 @@ module SciYAG
       end
 
       def apply!(f)
-        f.sort
+        f.sort!
       end
     end
   end
