@@ -218,10 +218,23 @@ module MetaBuilder
     # described class at a given time. It can be fed to #restore_state
     # and #recreate_state to restore the state to an already existing
     # instance or to create a new one from scratch.
+    #
+    # This function saves the raw parameters, as there is not much
+    # interest in converting to String and back from it.
+    #
+    # It saves a duplicate of the values, not the values themselves,
+    # to make sure it really represents the state of the objects at
+    # a given time.
     def save_state(instance)
       ret = {}
       for param in @param_list
-        ret[param.name] = param.get(instance)
+        val = param.get_raw(instance)
+        ret[param.name] = begin # Necessary as some classes can't be duped.
+                            val.dup
+                          rescue
+                            val # Typical case: nil, which still is a
+                            # valid value
+                          end
       end
       return ret
     end
@@ -232,12 +245,21 @@ module MetaBuilder
     def restore_state(state, target)
       for param in @param_list
         if state.has_key?(param.name)
-          param.set(target, state[param.name])
+          param.set_raw(target, state[param.name])
         end
       end
       return target
     end
 
+    # Returns the default state of an freshly created instance.
+    # This way, you can create a well-defined state of one
+    # instance via parameters set thus:
+    #
+    #  state = desc.default_state.update({'param' -> "My Value"})
+    def default_state
+      return save_state(instantiate)
+    end
+
     # Creates a new (default) instance of the #object_class associated
     # with this Description. Although this method takes additional
     # parameters that are fed to the new method of the class, its
@@ -246,7 +268,8 @@ module MetaBuilder
       return @object_class.new(*a)
     end
 
-    # Creates
+    # Creates a new instance of the #object_class associated with
+    # this description and fills its state
     def recreate_state(state)
       obj = instantiate
       restore_state(state, obj)
