@@ -4,8 +4,7 @@ setup_dir '.', "CTioga"
 declare_exec("bin/ctioga")
 declare_exec("bin/ctable")
 
-declare_file_set('SciYAG', 'Backends/backends.rb')
-declare_library('SciYAG/Backends', 'Backends/lib/*.rb')
+setup_dir 'Backends', "SciYAG"
 
 setup_dir('MetaBuilder', 'MetaBuilder')
 
