@@ -19,7 +19,7 @@ require 'CTioga/partition'
 
 module CTioga
 
-  Version::register_svn_info('$Revision: 791 $', '$Date: 2008-04-28 14:28:58 +0200 (Mon, 28 Apr 2008) $')
+  Version::register_svn_info('$Revision: 828 $', '$Date: 2008-08-07 11:29:21 +0200 (Thu, 07 Aug 2008) $')
 
   # A module to be included by the main PlotMaker instance. It
   # deals with various aspects of axes manipulations.
@@ -61,6 +61,8 @@ module CTioga
     
 
     # TODO: all the following attributes should go to PlotStyle!
+    # This would allow to remove the dirty ugly funcall hack for
+    # log values...
 
     # Whether to have X or Y log axes
     attr_accessor :x_log, :y_log
@@ -108,7 +110,10 @@ module CTioga
       end
     end
 
-    # Runs a block safely with an axis specification
+    # Runs a block safely with an axis specification.
+    #
+    # This function relies on the fact that it is being used
+    # from within a PlotMaker instance !!
     def run_with_axis(name)
       w = Utils::interpret_arg(name, AxisSpecification) {name}
       if current_plot_style.edges.axes.key? w
@@ -151,6 +156,24 @@ module CTioga
         @y_log = v
         add_elem_funcall(:yaxis_log_values=, v)
       end
+
+      parser.on("--reset-transformations",
+                "Reset axes transformations") do |v|
+        @y_log = false
+        @x_log = false
+        # TODO: remove that when this is move to PlotStyle:
+        # it should be setup automatically by the Container
+        # at the beginning of a plot...
+        add_elem_funcall(:xaxis_log_values=, false)
+        add_elem_funcall(:yaxis_log_values=, false)
+        @x_factor = nil
+        @y_factor = nil
+        @x_offset = nil
+        @y_offset = nil
+      end
+
+      
+
       parser.on("--comma",
                 "Uses a comma for the decimal separator") do 
         @decimal_separator = ','
@@ -243,7 +266,7 @@ module CTioga
                 "where WHAT = x(label),y(label) or t(itle).") do |w|
         run_with_label(w) do |label|
           a = Utils::interpret_arg(@args.shift, Justification) {false}
-          label.alignment = a if a
+          label.justification = a if a
         end
       end
 
