@@ -14,23 +14,11 @@
 # The backend structure...
 require 'SciYAG/backends'
 require 'MetaBuilder/factory'
+require 'CTioga/utils'
 
 module CTioga
 
-  # The position of the URL, used for getting the version
-  SVN_URL = '$HeadURL: svn+ssh://fourmond@rubyforge.org/var/svn/sciyag/releases/ctioga-1.6.2/lib/backends.rb $'
-
-  CTIOGA_VERSION = if SVN_URL =~ /releases\/ctioga-([^\/]+)/
-                     $1
-                   else
-                     "SVN version"
-                   end
-
-  # The current version of the program.
-  def CTioga.version
-    return CTIOGA_VERSION
-  end
-  
+  Version::register_svn_info('$Revision: 696 $', '$Date: 2007-12-06 20:59:20 +0100 (Thu, 06 Dec 2007) $')
 
   # This module handles all manipulations of backends.
   module Backends
@@ -40,8 +28,9 @@ module CTioga
     # Initializes the backend structure.
     def init_backend_structure
       @backend_factory = 
-        MetaBuilder::Factories::UniqueFactory.new(Backend, 'text')
-      SciYAG::Backend.logger = self.logger
+        MetaBuilder::Factories::UniqueFactory.new(SciYAG::Backends::Backend, 
+                                                  'text')
+      SciYAG::Backends::Backend.logger = self.logger
     end
 
     def backend
@@ -69,7 +58,7 @@ module CTioga
       @backend_factory.option_parser_factory(op) 
 
       op.separator "\nFilters to apply onto data:"
-      for filter_desc in Filter.description_list
+      for filter_desc in SciYAG::Backends::Filter.description_list
         filter_desc.parser_instantiate_option(op,
                                               self,
                                               :current_push_filter)
