@@ -21,12 +21,15 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # backends. Can come in dead useful for debugging, or if you intend to plot
 # with another data
 
+require 'Dobjects/Dvector'
 require 'CTioga/backends'
 require 'CTioga/log'
 require 'optparse'
 
 module CTioga
 
+  Version::register_svn_info('$Revision: 753 $', '$Date: 2008-02-26 15:03:52 +0100 (Tue, 26 Feb 2008) $')
+
   class CTable
     include Log
     include Backends
@@ -99,7 +102,8 @@ module CTioga
     # though, as command-line arguments can still override this.
     def run(cmd_line_args,*extra_args, &a)
       $stderr.puts <<"EOBANNER" if @print_banner
-This is ctable version #{CTioga.version}, copyright (C) 2006 Vincent Fourmond
+This is ctable version #{Version.version}, 
+copyright (C) 2006-2007 Vincent Fourmond. 
 ctable comes with absolutely NO WARRANTY. This is free software, you are 
 welcome to redistribute it under certain conditions. See the COPYING file
 in the original tarball for details. You are also welcome to contribute if
