@@ -13,120 +13,13 @@
 
 require 'Tioga/Utils'
 require 'CTioga/log'
-
-# A small add-on to the Array class, to make it easy to convert to
-# frame specifications.
-
-class Array
-
-  def to_frame(spec = "%s")
-    i = 0
-    h = {}
-    for side in %w(left right top bottom)
-      h[ spec % side] = self[i]
-      i += 1
-    end
-    return h
-  end
-
-end
+require 'CTioga/dimension'
+require 'CTioga/boundaries'
 
 
 module CTioga
 
-  Version::register_svn_info('$Revision: 774 $', '$Date: 2008-03-05 11:43:20 +0100 (Wed, 05 Mar 2008) $')
-
-  # A class which represents a dimension, either absolute or
-  # relative.
-  class Dimension
-
-    include Tioga::Utils
-
-    # The type of the dimension :
-    # * :abs means absolute
-    # * :rel is relative
-    attr_accessor :type
-
-    # The actual dimension. Its meaning depends on the
-    # value of type:
-    # * :abs : the value is in bp points
-    # * :rel : the value is a fraction of the corresponding size
-    #   in the given plot.
-    attr_accessor :value
-
-    # Creates a dimension. If the dimension contains a letter,
-    # it will be interpreted in terms of a TeX size.
-    # If it contains a percent - or nothing, it will be interpreted as
-    # a relative measure. If it is a float, it will be interpreted
-    # as a relative measure unless _type_ is not nil.
-    def initialize(spec, type = nil)
-      case spec
-      when /^\s*[\d.]+[a-zA-Z]+\s*$/
-        @type = :abs
-        @value = tex_dimension_to_bp(spec)
-      when /^\s*([\d.]+)\s*%\s*$/
-        @type = :rel
-        @value = $1.to_f * 0.01 # Value in percents
-      when Float
-        @value = spec
-        @type = type || :rel
-      when /^\s*([\d.]+)/
-        @value = spec.to_f
-        @type = type || :rel
-      end
-    end
-
-    # Converts self to a relative dimension. _frames_ is the frames
-    # of the current object (outer_frames) expressed in big points.
-    def to_relative(frames, side = :horizontal)
-      # The easy thing first:
-      return @value if @type == :rel
-      if side == :horizontal
-        return @value/((frames[1] - frames[0]).abs)
-      else
-        return @value/((frames[3] - frames[2]).abs)
-      end
-    end
-
-    # Converts self to an absolute dimension. _frames_ is the frames
-    # of the current object (outer_frames) expressed in big points.
-    def to_absolute(frames, side = :horizontal)
-      # The easy thing first:
-      return @value if @type == :abs
-      if side == :horizontal
-        return @value * ((frames[1] - frames[0]).abs)
-      else
-        return @value * ((frames[3] - frames[2]).abs)
-      end
-    end
-
-    # Scales the dimension by the given factor
-    def scale!(fact)
-      @value *= fact
-      return self
-    end
-
-
-    # Converts an absolute dimension in terms of a relative
-    # one, using the given frames.
-    def Dimension.absolute_to_relative(dimensions, frames)
-      ret_val = []
-      ret_val[0] = dimensions[0]/((frames[1] - frames[0]).abs)
-      ret_val[1] = dimensions[1]/((frames[1] - frames[0]).abs)
-      ret_val[2] = dimensions[2]/((frames[3] - frames[2]).abs)
-      ret_val[3] = dimensions[3]/((frames[3] - frames[2]).abs)
-      return ret_val
-    end
-
-    def self.update_extensions(extensions, new_ext)
-      4.times do |i|
-        extensions[i] = new_ext[i] unless  new_ext[i] < extensions[i]
-      end
-      return extensions
-    end
-
-
-  end
+  Version::register_svn_info('$Revision: 836 $', '$Date: 2008-10-10 01:27:54 +0200 (Fri, 10 Oct 2008) $')
 
   # This class merely stores various information about the layout,
   # such as the desired mimimum amount of padding on the sides,
@@ -328,7 +221,7 @@ module CTioga
       case @object.layout_preferences.legend_position
       when :inside
         # Use the legend_spec without any other modification.
-        return  @object.layout_preferences.legend_spec
+        return @object.layout_preferences.legend_spec
       else
         ext = legend_extension(t)
         mar = Dimension.absolute_to_relative(ext, frame)
@@ -453,10 +346,48 @@ module CTioga
   # 'alternative axes' things.
   class FixedLayout < SimpleLayout
 
+    # The margins of the given object, either an array or a hash
+    # with plot_%s_margin
+    attr_accessor :position
+
+    # Creates a Fixed layout for the given object.
+    def initialize(ro, ch = [], children = [])
+      super
+      @position = [0, 0, 0, 0]
+    end
+
     # Return default plot specifications: we don't take the
     # legend into consideration, for instance.
     def legend_specs(object, t = nil)
-      return [0,0,0,0].to_frame("plot_%s_margin")
+
+      # First, the position of the layout:
+      if @position.is_a? Hash
+        specs = @position.dup
+      else
+        specs = @position.to_frame("plot_%s_margin")
+      end
+
+
+      # Then handling of the legends if applicable:
+      # TODO: this will fail for normal legends....
+      if @object.display_legend?
+        case @object.layout_preferences.legend_position
+        when :inside
+          a = @object.layout_preferences.legend_spec
+          
+          legend = Utils::frame_to_array(a, "legend_%s_margin")
+          frame = Utils::frame_to_array(specs, "plot_%s_margin")
+          
+          target = Utils::compose_margins(frame, legend)
+          a = target.to_frame("legend_%s_margin")
+        else
+          warn "Legend position #{@object.layout_preferences.legend_position.inspect} not implemented for FixedLayout"
+          a = {}
+        end
+        return specs.merge(a)
+      else
+        return specs
+      end
     end
 
   end
