@@ -12,6 +12,70 @@
 # GNU General Public License for more details (in the COPYING file).
 
 
+# TODO, the main one:
+# 
+# It currently is a pain to make complex plots with ctioga. A real
+# pain. What could be done to improve the situation ?
+# 
+# * hide the difference between edges and axes.
+# * the layout mechanism is not comfortable enough to work with, especially
+#   with the need for relative positioning.
+#
+# Would it be possible to allow for the 'real size' to be determined
+# *afterwards* ? 
+
+# TODO, an even bigger one:
+# Switch to a real command-based plotting program:
+#  - any single operation that is realized by ctioga would be a command
+#  - every single of these commands would take a given (fixed) number of
+#    parameters (we should take care about boolean stuff)
+#  - every command would be of course reachable as command-line options
+#    but it could also be within files
+#  - in these files, provide an additional mechanism for quickly defining
+#    variables and do variable substitution.
+#  - one command (plus arguments) per line, with provisions for
+#    line-splitting
+#  - allow some kind of 'include' directives (that would also be used for
+#    cmdline inclusion of files)
+#  - command-line arguments and command files could intermix (that *would*
+#    be fun, since it would allow very little changes to a command-line
+#    to change significantly the look of a file...!)
+#  - command files would be specified using @file ?
+#  - in the absence of --name commands, output would go to the named file ?
+#  - LONG TERM: allow conditionals and variable
+#    definition/substitution on command-line ?
+#
+#  Each command could take *typed* arguments. That would allow typed
+#  variables along with a string-to-type conversion ? (is that useful ?)
+#
+#  Provide *optional* hash-like arguments that probably could not be used
+#  in the command-line, but could be in the file.
+#
+#  Provide self-documentation in each and every command
+#
+#  Manipulations of a buffer stack - including mathematical
+#  expressions; provide commands to only *load* a file, but not
+#  necessarily import it.
+#
+#  Provide a way to 'save' a command-line into a command-file.
+#
+#  Write as many test suites as possible ??
+#
+#  Merge Metabuilder and Backends into the ctioga code base. There's
+#  no need for extra complexity.
+#
+#  That requires a huge amount of work, but on the other hand, that
+#  would be much more satisfactory than the current mess.
+#
+#  Commands would be part of "groups".
+#
+#  Release a new version of ctioga before that.
+#
+#  Don't rely on huge mess of things !
+#
+#  Then, I could have some small fun and write a 
+
+
 
 # Very important for command-line parsing
 require 'optparse'
@@ -24,8 +88,6 @@ require 'CTioga/styles'
 # require 'CTioga/movingarrays'
 # And, most important of all, elements
 require 'CTioga/elements'
-require 'CTioga/curves'
-require 'CTioga/tioga_primitives'
 
 # The debugging facility
 require 'CTioga/debug'
@@ -42,6 +104,9 @@ require 'CTioga/themes'
 require 'CTioga/axes'
 require 'CTioga/structures'
 
+# Legends
+require 'CTioga/legends'
+
 
 # for interpreting the CTIOGA environment variable
 require 'shellwords'
@@ -50,7 +115,7 @@ require 'MetaBuilder/metabuilder'
 
 module CTioga
 
-  Version::register_svn_info('$Revision: 790 $', '$Date: 2008-04-28 14:28:22 +0200 (Mon, 28 Apr 2008) $')
+  Version::register_svn_info('$Revision: 882 $', '$Date: 2009-02-24 15:23:12 +0100 (Tue, 24 Feb 2009) $')
 
 
 
@@ -141,6 +206,12 @@ EOD
     # The PNG's size:
     attr_accessor :png_size
 
+    # Whether to create separate legends
+    attr_accessor :separate_legends
+    
+    # Whether to automatically add a legend to all curves
+    attr_accessor :autolegends
+
     def initialize
       # The first thing to do is to setup logging, as you really
       # want to be able to communicate with users, don't you ?
@@ -237,6 +308,9 @@ EOD
       # The standard PNG density...
       @png_oversampling = 2
 
+      # We don't produce SVG output by default
+      @svg = false
+
       # The default padding;
       @default_padding = []
       4.times do 
@@ -445,6 +519,18 @@ EOD
         current_plot_style.background_color = c
       end
 
+      @parser.on("--[no-]watermark [TEXT]",
+                 "Writes a text as a watermark at the back ", 
+                 "of the plot") do |c|
+        current_plot_style.watermark_text = c
+      end
+
+      @parser.on("--watermark-color [COLOR]",
+                 "Chooses the color of the watermark") do |c|
+        c = CTioga.get_tioga_color(c) if c
+        current_plot_style.watermark_color = c
+      end
+
       @parser.on("--aspect-ratio [RATIO]",
                  "Sets the aspect ratio (defaults to 1)") do |a|
         a = 1.0 unless a
@@ -479,6 +565,8 @@ EOD
         current_object.rescale = safe_float(fact)
       end
 
+
+      # TODO: this should probably move to PlotStyle
       @parser.on("--padding PADDING",
                  "Changes the padding for the current object",
                  "and subsequent ones") do |pad|
@@ -550,13 +638,19 @@ EOD
                  "Creates an inset with the given",
                  "specifications (x,y:w[xh] or x1,y1;x2,y2)" ) do |a|
         plot = SubPlot.new(:subplot, current_object)
-        plot.show_legend = false
+        plot.show_legend = true
         enter_child_object(plot)
+        # TODO - high priority !
+        # implement a way to specify insets with *real* tex dimensions
+        # !!!! (such as 3cm,2cm:5cm) !
+        #
+        # This would *really* make way for real-size graphs
         margins = Utils::inset_margins(a)
         debug "inset margins: #{margins.inspect}"
-        # With force_position, there is no need for a layout.
-        current_object.force_position = margins
-        # We redirect all legends for the inset to the parent.
+        current_object.convert_layout(FixedLayout)
+        current_object.layout.position = margins
+        # By default, we redirect all legends for the inset
+        # to the parent.
         current_object.accept_legend = false
       end
 
@@ -580,7 +674,8 @@ EOD
         enter_child_object(plot)
         margins = Utils::inset_margins(a)
         debug "zoom margins: #{margins.inspect}"
-        current_object.force_position = margins
+        current_object.convert_layout(FixedLayout)
+        current_object.layout.position = margins
       end
 
       @parser.on("--next-inset SPEC",
@@ -588,7 +683,7 @@ EOD
                  "various style information are carried from",
                  "the previous inset") do |a|
         plot = SubPlot.new(:subplot, current_object)
-        plot.show_legend = false
+        plot.show_legend = true
         old = leave_child_object
         enter_child_object(plot)
 
@@ -597,8 +692,8 @@ EOD
 
         margins = Utils::inset_margins(a)
         debug "inset margins: #{margins.inspect}"
-        # With force_position, there is no need for a layout.
-        current_object.force_position = margins
+        current_object.convert_layout(FixedLayout)
+        current_object.layout.position = margins
         # We redirect all legends for the inset to the parent.
         current_object.accept_legend = false
       end
@@ -654,6 +749,11 @@ EOD
         current_object.disable_legend = false
       end
 
+      @parser.on("--[no-]forward-legends",
+                 "Forwards the legends to the parent object") do |v|
+        current_object.accept_legend = ! v
+      end
+
       # Black magic is starting here !
       @parser.on("--grid SPEC",
                  "Creates a grid. SPEC is column|row=nb") do |s|
@@ -858,23 +958,9 @@ EOD
         set_frame_margins(margins_from_text(val))
       end
 
+      Legends::fill_option_parser(@parser, self)
 
-      @parser.separator "\nLegends and texts:"
-      @parser.on("-l","--[no-]legend [LEGEND]",
-                 "Sets the legend of the next curve.") do |l|
-        override_style.legend = l
-      end
-
-      @parser.on("--[no-]auto-legend", 
-                 "Whether to automatically add legends",
-                 "to curves") do |l|
-        @autolegends = l
-      end
-
-      @parser.on('-N', "--no-legends", 
-                 "Alias for --no-auto-legend") do
-        @autolegends = false
-      end
+      @parser.separator "\nTexts:"
 
       ## Default TeX fontsize
       @parser.on("--fontsize NB",
@@ -882,12 +968,6 @@ EOD
         @tex_fontsize = size
       end
 
-      ## Legend scale
-      @parser.on("--legend-scale FACT",
-                 "Sets the scale for the legends") do |l|
-        add_elem_funcall(:legend_scale=, Float(l))
-      end
-
       @parser.on("--tick-label-scale SCALE",
                  "Sets the scale of the text for tick labels") do |l|
         add_elem_funcall(:xaxis_numeric_label_scale=,Float(l))
@@ -905,29 +985,6 @@ EOD
         end
       end
 
-      @parser.on("--legend-pos SPEC", 
-                 "Sets the legend position and its size.",
-                 "SPEC looks like pos,size[,delta]") do |a|
-        w,s,d = a.split /\s*,\s*/
-        if d
-          warn "The delta specification (#{d}) for #{a} is ignored"
-        end
-        debug "Legend position #{w.inspect} #{s.inspect}"
-        current_object.layout_preferences.legend_position = w.to_sym
-        current_object.layout_preferences.legend_size = Dimension.new(s)
-      end
-
-      @parser.on("--legend-inside SPEC", 
-                 "Makes a legend inside the plot.",
-                 "See --inset for the format of SPEC") do |a|
-        margins = Utils::inset_margins(a)
-        specs = margins.to_frame("legend_%s_margin")
-        debug "Specs: #{specs.inspect}"
-        current_object.layout_preferences.legend_position = :inside
-        current_object.layout_preferences.legend_spec = specs
-      end
-
-
       @parser.separator "\nGraphic primitives:"
       @parser.on("-d","--draw SPEC",
                  "Draw a graphic primitive") do |spec|
@@ -999,6 +1056,11 @@ EOD
         @fig_name = name
       end
 
+      @parser.on("-o", "--output NAME",
+                 "Produces a graph named NAME with the current output") do |name|
+        output_figure(name)
+      end
+
       @parser.on("--echo", "Prints command-line to standard output") do
         puts "Command-line used:"
         puts @command_line
@@ -1039,7 +1101,7 @@ EOD
       end
 
       @parser.on("--png SIZE", 
-                 "Runs ctioga as usual, but runs convert afterwards",
+                 "Runs ctioga as usual, and runs convert afterwards",
                  "to produce a nice PNG file") do |s|
         @png = true
         s =~ /(\d+)x(\d+)/
@@ -1054,6 +1116,13 @@ EOD
         @png_oversampling = s.to_f
       end
 
+      @parser.on("--svg", 
+                 "Runs ctioga as usual, and runs pdf2svg afterwards",
+                 "to produce a nice SVG file") do |s|
+        @svg = true
+      end
+
+
       @parser.on("--args FILE",
                  "Reads argument from FILE, *one per",
                  "line* and then resumes normal processing") do |v|
@@ -1071,6 +1140,11 @@ EOD
         puts "as long as they are still unique"
         exit
       end
+
+      @parser.on_tail("--version", "Show version number") do
+        puts "This is ctioga version " + Version::version
+        exit
+      end
     end
 
 
@@ -1240,7 +1314,7 @@ EOD
             debug "Remaining args: #{@args.inspect}"
             error "Invalid option: #{o.args.first}. Please run " + 
               "ctioga --help to have a list of valid ones"
-            exit
+            exit 1
           end
         rescue Exception => ex
           # Do not catch normal exit !
@@ -1250,7 +1324,7 @@ EOD
           fatal "ctioga encountered the following problem: #{ex.to_s}"
           debug "Error backtrace: #{ex.backtrace.join "\n"}"
           fatal "Aborting"
-          exit
+          exit 1
         end
       end
     end
@@ -1276,6 +1350,15 @@ EOD
         debug_patterns(t)
       end
 
+      # We use Vincent's algorithm for major ticks when available ;-)...
+      begin
+        t.vincent_or_bill = true
+        info "Using Vincent's algorithm for major ticks"
+      rescue
+        info "Using Bill's algorithm for major ticks"
+      end
+
+
       return unless @root_object.number > 0 
 
       # Asking the theme to do something.
@@ -1313,6 +1396,7 @@ EOD
       for funcall in @init_funcalls
         funcall.do(t)
       end
+
     end
 
     # Runs the code to make the actual figure.
@@ -1324,7 +1408,7 @@ EOD
     def banner
       <<"EOBANNER" 
 This is ctioga version #{Version::version}
-ctioga is copyright (C) 2006, 2007 by Vincent Fourmond 
+ctioga is copyright (C) 2006, 2007, 2008 by Vincent Fourmond 
 
 ctioga comes with absolutely NO WARRANTY. This is
 free software, you are welcome to redistribute it under certain
@@ -1334,14 +1418,8 @@ the manual page where to ask.
 EOBANNER
     end
 
-    # Runs the plots, using the arguments given in the command-line.
-    # Now delegates to some other small functions.
-    def run(args)
-
-
-      # First, we parse command-line arguments:
-      parse_command_line_arguments(args)
-      
+    # Output a figure with the given name
+    def output_figure(fig_name)
       # now, we plot the stuffs... if there is actually
       # something to be plotted ;-) !
 
@@ -1351,6 +1429,7 @@ EOBANNER
       # The files will get cleaned up anyway.
       t.autocleanup = false
 
+
       # Now, we must use real_size stuff !! (default 12cmx12cm)
       # This is not part of setup_figure_maker, as it can strongly interfere
       # when ctioga is used to produce a figure.
@@ -1361,14 +1440,14 @@ EOBANNER
       setup_figure_maker(t)
       
 
-      t.def_figure(@fig_name) {
+      t.def_figure(fig_name) {
         do_figure(t)
       }
 
       debug "Contents of the main FigureMaker object: " +
         figmaker_options(t)
 
-      info "Generating file '#{@fig_name}.pdf'"
+      info "Generating file '#{fig_name}.pdf'"
       if @fast
         # It isn't that fast, actually.
         info "Producing a fast version"
@@ -1384,26 +1463,26 @@ EOBANNER
             show_marker(dict)
           end
         end
-        t.create_figure_temp_files(t.figure_index(@fig_name))
+        t.create_figure_temp_files(t.figure_index(fig_name))
         base_name = if t.save_dir
-                      File.join(t.save_dir,@fig_name)
+                      File.join(t.save_dir,fig_name)
                     else
-                      @fig_name
+                      fig_name
                     end
         # Remove the _figure.txt files
         File.rename(base_name + "_figure.pdf", base_name + ".pdf")
       else
-        t.make_preview_pdf(t.figure_index(@fig_name))
+        t.make_preview_pdf(t.figure_index(fig_name))
       end
 
       if @eps
         info "Attempting to create an EPS file, watch out error messages"
         # First, we convert the _figure.pdf into eps with pdftops
-        cmd = "pdftops -eps #{output_filename('_figure.pdf')}"
+        cmd = "pdftops -eps #{output_filename('_figure.pdf', fig_name)}"
         debug "Running #{cmd}"
         system cmd
-        f = output_filename('.tex')
-        new = output_filename('.new.tex')
+        f = output_filename('.tex', fig_name)
+        new = output_filename('.new.tex', fig_name)
         debug "Modifying #{f}"
         orig = open(f)
         out = open(new, "w")
@@ -1416,15 +1495,21 @@ EOBANNER
         out.close
 
         spawn "latex #{new}"
-        spawn "dvips -o #{output_filename('.eps')} -t unknown -T " +
-          "#{@real_size.gsub(/x/,',')} #{output_filename('.new.dvi')}"
+        spawn "dvips -o #{output_filename('.eps', fig_name)} -t unknown -T " +
+          "#{@real_size.gsub(/x/,',')} #{output_filename('.new.dvi', fig_name)}"
       end
 
       if @png
         # We create the PNG file:
         spawn "convert -density #{(@png_oversampling * 72).to_i} "+
-          "#{output_filename('.pdf')} -resize " +
-          "#{@png_size.join('x')} #{output_filename('.png')}"
+          "#{output_filename('.pdf', fig_name)} -resize " +
+          "#{@png_size.join('x')} #{output_filename('.png', fig_name)}"
+      end
+
+      if @svg
+        # We create the SVG file
+        spawn "pdf2svg #{output_filename('.pdf', fig_name)} " +
+          "#{output_filename('.svg', fig_name)}"
       end
 
       
@@ -1433,7 +1518,7 @@ EOBANNER
         index = 0
         info "Creating separate lengends"
         for style in @separate_legend_styles 
-          name = sprintf "%s_legend_%02d", @fig_name, index
+          name = sprintf "%s_legend_%02d", fig_name, index
           index += 1
           t.def_figure(name) {
             t.set_device_pagesize(@separate_legend_width * 10,
@@ -1482,16 +1567,16 @@ EOBANNER
         # we display the output file:
         info "Starting the viewer #{@viewer} as requested"
         pdf_file = if t.save_dir
-                     File.join(t.save_dir,@fig_name+".pdf")
+                     File.join(t.save_dir,fig_name+".pdf")
                    else
-                     @fig_name+".pdf"
+                     fig_name+".pdf"
                    end
         system("#{@viewer} #{pdf_file}")
       end
       
       if files_to_remove
         files_to_remove.collect! {|s| 
-          output_filename(s)
+          output_filename(s, fig_name)
         }
         files_to_remove << "pdflatex.log" 
         info "Cleaning up temporary files"
@@ -1504,6 +1589,19 @@ EOBANNER
           end
         end
       end
+
+    end
+
+    # Runs the plots, using the arguments given in the command-line.
+    # Now delegates to some other small functions.
+    def run(args)
+
+      # First, we parse command-line arguments:
+      parse_command_line_arguments(args)
+
+      # Then, we spit the output:
+      output_figure(@fig_name)
+
     end
 
   end
