@@ -18,7 +18,7 @@ require 'CTioga/shortcuts'
 
 module CTioga
 
-  Version::register_svn_info('$Revision: 796 $', '$Date: 2008-06-06 13:49:26 +0200 (Fri, 06 Jun 2008) $')
+  Version::register_svn_info('$Revision: 869 $', '$Date: 2009-01-13 17:56:12 +0100 (Tue, 13 Jan 2009) $')
 
   # The namespace for themes. Supposedly, all themes should end up
   # here.
@@ -52,7 +52,7 @@ module CTioga
         return []
       end
 
-      # A function to be reimplemented by children to handle color_sets.
+      # A function to be reimplemented by children to handle color_
       def choose_set(type,set)
         warn "Theme #{self.class.name} does not support sets"
       end
@@ -134,16 +134,20 @@ module CTioga
       end
     end
 
-    DisableRe = /no|off/i
+    DisableRe = /no(ne)?|off/i
 
     # Processes a style argument.
 
     # A correspondance style_element -> style type
     StyleTypes = {
       :color => :color,
+      :colors => :color,
       :marker => :marker,
+      :markers => :marker,
       :marker_color => :color,
+      :markers_colors => :color,
       :line_style => :line_style,
+      :linestyle => :line_style,
       :linewidth => :float,
       :error_bar_color => :color,
       :marker_scale => :float,
@@ -170,7 +174,6 @@ module CTioga
               MetaBuilder::ParameterType.from_string(StyleTypes[style_element],
                                                      value)
             rescue Exception => e
-              # TODO: ignore the parameter when the
               if e.is_a? MetaBuilder::ParameterType::IncorrectInput
                 warn "The argument for #{style_element} was not recognized:"
                 warn e.message
@@ -206,7 +209,7 @@ module CTioga
         style_argument(:marker_color, val)
       end
 
-      parser.on("--line-style STYLE",
+      parser.on("--[no-]line-style STYLE",
                 "Sets the line style") do |val|
         style_argument(:line_style, val)
       end
@@ -430,23 +433,34 @@ module CTioga
                   "(#{@theme.sets[type].available_sets.join(' ')})") do |set|
           debug "Using set '#{set}' for #{type} on theme " +
             "#{current_theme.class}"
-          begin
-            # If there is one '|', we split the 
-            if set =~ /\|/
-              set = SpecialArray.new(set.split(/\|/).map do |x|
-                MetaBuilder::ParameterType.
-                from_string(StyleTypes[name.tr('-','_').to_sym], x)
-              end)
-              info "Setting set #{name} to objects #{set.inspect}"
-            else
-              set = MetaBuilder::ParameterType.
-                from_string(StyleTypes[name.tr('-','_').to_sym], set)
-              info "Setting set #{name} to single-value object #{set.inspect}"
+          if target_set = current_theme.sets[type]
+            begin
+              # If there is one '|', we split the 
+              if ! target_set.valid_set?(set)
+                debug "#{set} is not a named set for #{type}, " +
+                  "trying other interpretations"
+                
+                if set =~ /\|/
+                  set = SpecialArray.new(set.split(/\|/).map do |x|
+                                           MetaBuilder::ParameterType.
+                                             from_string(StyleTypes[type], x)
+                                         end)
+                  info "Setting set #{name} to objects #{set.inspect}"
+                else
+                  set = MetaBuilder::ParameterType.
+                    from_string(StyleTypes[type], set)
+                  info "Setting set #{name} to single-value object #{set.inspect}"
+                end
+              end
+              current_theme.choose_set(type, set)
+            rescue Exception => e
+              error "Set #{set} was not understood for #{name}, ignoring"
+              debug "Exception raised on set interpretation code: #{e.inspect}"
             end
-          rescue Exception => e
-            debug "Exception raised on set detection code: #{e.inspect}"
+          else
+            warn "Theme #{current_theme.class} does not appear to have " +
+              "sets for #{type}, ignoring"
           end
-          current_theme.choose_set(type, set)
         end
       end
 
