@@ -16,6 +16,7 @@ require 'Tioga/tioga'
 require 'CTioga/themes'
 require 'CTioga/movingarrays'
 
+
 module CTioga
 
   module Themes
@@ -35,11 +36,11 @@ module CTioga
                      marker_color_set = :"=>color",
                      linestyle_set = Line_Type_Solid)
         @sets = {
-          :colors => MovingArray.new(Data::COLORS, color_set),
-          :markers => MovingArray.new(Data::MARKERS, marker_set),
-          :markers_colors => MovingArray.new(Data::COLORS, 
+          :colors => MovingArray.new(Styles::COLORS, color_set),
+          :markers => MovingArray.new(Styles::MARKERS, marker_set),
+          :markers_colors => MovingArray.new(Styles::COLORS, 
                                           marker_color_set),
-          :linestyle => MovingArray.new(Data::LINES, linestyle_set)
+          :linestyle => MovingArray.new(Styles::LINES, linestyle_set)
         }
      end
 
