@@ -21,9 +21,11 @@ module CTioga
     class MonoTheme < ClassicalTheme
       
       def initialize
-        super('black-only', 'standard', 'black-only', 'standard')
+        super(Tioga::FigureConstants::Black, 'standard', 
+              Tioga::FigureConstants::Black, 'standard')
       end
 
+
     end
 
   end
