@@ -134,7 +134,7 @@ module CTioga
   module Version
 
     # The position of the URL, used for getting the version
-    SVN_URL = '$HeadURL: svn+ssh://fourmond@rubyforge.org/var/svn/sciyag/releases/ctioga-1.8/lib/utils.rb $'
+    SVN_URL = '$HeadURL: svn+ssh://rubyforge.org/var/svn/sciyag/releases/ctioga-1.10/lib/utils.rb $'
     
     CTIOGA_VERSION = if SVN_URL =~ /releases\/ctioga-([^\/]+)/
                        $1
