@@ -3,7 +3,7 @@
 # I add some features to ctioga, I don't break everything existing.
 # As such, it also stands as a 'feature list' for ctioga.
 
-export CTIOGA="--xpdf --clean-all --math"
+. ./test_style.sh
 
 ctioga -t 'Basic curve' 'sin(x)'
 
