@@ -12,6 +12,12 @@ ctioga -N -t 'Markers' \
     --marker auto 'sin(x)**2' 'cos(x)**2'
 ctioga -N -t 'Dot clouds' \
     --marker auto --marker-scale 0.2 --line-style no 'x**2' '1 - x**2'
+
+# Special sets
+ctioga -N -t 'Unusual set specifications' \
+    --marker auto --color-set 'Red|Blue|Pink' \
+    --line-style-set Dashes 'x**2 + 10*0##9'
+
 # Style manipulations
 ctioga -N -t 'Reset override' \
     --marker auto --marker-scale 0.2 --line-style no 'x**2' '1 - x**2' \
@@ -33,3 +39,5 @@ ctioga -N -t 'Backgrounds with --grid' \
     --next 'tan(x)' --next --background Chiffon \
     'x**2' 'x**2 + 10'
 
+
+ 
\ No newline at end of file
