@@ -3,3 +3,6 @@
 # You can do whatever you want with this file.
 
 export CTIOGA="--echo --xpdf --clean-all --math "
+if [ "$DEBUG" ]; then
+    export CTIOGA="$CTIOGA --debug "
+fi;
