@@ -3,7 +3,7 @@
 # I add some features to ctioga, I don't break everything existing.
 # As such, it also stands as a 'feature list' for ctioga.
 
-export CTIOGA="--xpdf --clean-all --math"
+. ./test_style.sh
 
 # First, some basic stuff
 ctioga -t 'Basic curve' 'sin(x)'
@@ -19,5 +19,6 @@ ctioga -N -t 'Dot clouds' \
 
 # Then, insets:
 
-ctioga -N 'x**2' --inset .5,.5:.4 'cos(x)'
+ctioga -N -t 'Inset (with title)' 'x**2' --inset .5,.5:.4 \
+    -t 'Title inset' 'cos(x)'
 
